InkChildren

Trait InkChildren 

pub trait InkChildren {
    // Required methods
    fn orphans(&self) -> Vec<Widget>;
    fn children(&self) -> Vec<InkWrapper<Widget>>;
}
containers which can contain multiple widgets.

Required Methods

fn orphans(&self) -> Vec<Widget>

equivalent to .children() but stripped of their wrapper, effectively making them orphans (meaning their relative position in the graph cannot be determined anymore).

fn children(&self) -> Vec<InkWrapper<Widget>>

children wrappers, which conserve their relative index in the graph.

Implementors