pub trait SiblingOrNested {
// Required method
fn sibling_or_nested(&self, searched: &[usize]) -> bool;
}Expand description
belongs to the same level or is nested below, in a tree hierarchy
pub trait SiblingOrNested {
// Required method
fn sibling_or_nested(&self, searched: &[usize]) -> bool;
}belongs to the same level or is nested below, in a tree hierarchy