WidgetTree

Trait WidgetTree 

pub trait WidgetTree {
    // Required methods
    fn get_widget_classname(&self, path: &[usize]) -> Option<String>;
    fn get_path_names(&self, path: &[usize]) -> Option<Vec<String>>;
    fn get_path_indexes(&self, path: &[&str]) -> Option<Vec<usize>>;
    fn get_partial_path_indexes(&self, path: &[&str]) -> (Vec<usize>, String);
}

Required Methods

fn get_widget_classname(&self, path: &[usize]) -> Option<String>

return the widget type

fn get_path_names(&self, path: &[usize]) -> Option<Vec<String>>

return the full path names to the widget

fn get_path_indexes(&self, path: &[&str]) -> Option<Vec<usize>>

return the full path indexes to the widget

fn get_partial_path_indexes(&self, path: &[&str]) -> (Vec<usize>, String)

return the full path indexes to the widget (or the partial path indexes until where it failed) alongside the last name searched.

Implementors